California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 45 - LEGISLATIVE TERM LIMITS. LOCAL VOTER PETITIONS. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1233779 | CITIZENS' RIGHT TO PETITION, YES ON PROP. 45, A COALITION OF CITIZENS, ORGANIZATIONS AND ENTITIES, INCLUDING POLITICAL COMMITTEES, REPRESENTING THE INTERESTS OF SENIOR CITIZENS, TAXPAYERS, TEACHERS, C | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1236419 | NO ON 45: STOP THE POLITICIANS, SPONSORED BY AMERICANS FOR LIMITED TERMS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1239930 | YES ON 45. CITIZENS RIGHT TO VOTE. A COALITION TO IMPROVE TERM LIMITS SPONSORED BY FIREFIGHTERS, TEACHERS, SENIORS, RETAILERS, THE CHAMBER OF COMMERCE AND THE LEAGUE OF WOMEN VOTERS. | SUPPORT